@@ -34,10 +34,10 @@ class HelpfulCmd(click.Command):
         click.echo(
             '''
             -m, --method, 
-                    A deep learning method. It can be any below.
-                    AlexNet | BiRNN | RNN | Seq2Seq | 
-                    CNN | ConvMixer64 | DSConv | LSTMCNN |
-                    MobileNet | ResNet18 | ResNet50 | SEResNet |
+                A deep learning method. It can be any below.
+                AlexNet | BiRNN | RNN | Seq2Seq | 
+                CNN | ConvMixer64 | DSConv | LSTMCNN |
+                MobileNet | ResNet18 | ResNet50 | SEResNet
             '''
         )
         click.echo(
@@ -68,7 +68,7 @@ class HelpfulCmd(click.Command):
         A deep learning method. It can be any below.
         AlexNet | BiRNN | RNN | Seq2Seq | 
         CNN | ConvMixer64 | DSConv | LSTMCNN |
-        MobileNet | ResNet18 | ResNet50 | SEResNet |
+        MobileNet | ResNet18 | ResNet50 | SEResNet
     '''
 )
 @click.option('-sm', '--smile_fpn', default='data/example/5757.txt', help='a small molecule file that contains only smile strings')
